@@ -67,7 +67,11 @@ async def market_linechart(figsize: Tuple[int,int], market_history:list, title:s
     sell = []
     T = []
     for i in range(N):
-        T.append(datetime.fromtimestamp(market_history[-i-1][0]).strftime("%H:%M"))
+        T.append(
+            datetime.fromtimestamp(market_history[-i-1][0]).strftime("%d-%H:%M")
+            if datetime.fromtimestamp(market_history[-i-1][0]).strftime("%H:%M") in T
+            else datetime.fromtimestamp(market_history[-i-1][0]).strftime("%H:%M")
+            )
         buy.append(market_history[-i-1][1])
         sell.append(market_history[-i-1][2])
     else:
@@ -100,7 +104,11 @@ async def market_candlestick(figsize: Tuple[int,int],datalenth: int, market_hist
     sell = []
     T = []
     for i in range(N):
-        T.append(datetime.fromtimestamp(market_history[-i-1][0]).strftime("%H:%M"))
+        T.append(
+            datetime.fromtimestamp(market_history[-i-1][0]).strftime("%d-%H:%M")
+            if datetime.fromtimestamp(market_history[-i-1][0]).strftime("%H:%M") in T
+            else datetime.fromtimestamp(market_history[-i-1][0]).strftime("%H:%M")
+            )
         buy.append(market_history[-i-1][1])
         sell.append(market_history[-i-1][2])
     else:
@@ -134,7 +142,7 @@ async def market_candlestick(figsize: Tuple[int,int],datalenth: int, market_hist
     candlestick_ohlc(ax, dataList, width = 0.4, colorup = 'red', colordown = 'limegreen', alpha = 1)
     N = len(dataList)
     plt.xlim((-1,N))
-    plt.xticks(range(n), xtime, rotation = 30)
+    plt.xticks(range(N), xtime, rotation = 30)
     plt.subplots_adjust(left=0.03, right=0.97, top=0.9, bottom=0.1)
     plt.title(title, fontproperties=font)
     plt.grid(True, linestyle='--', alpha=0.3)
